from setuptools import setup

setup(
    name='TeleAds',
    packages=['teleads'],
    version='0.1.5',
    description='TeleAds SDK',
    long_description_content_type="text/markdown",
    python_requires='>=3.7',
    classifiers=[
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
)
